# PKU - PKMN Utility Library

<p align="center">
    <img src="https://codeberg.org/wry/pku-lib/raw/branch/main/assets/icon.png" alt="Pyukumuku sprite">
</p>

<p align="center">Pyukumuku</p>

## Environment

- Git 2.48.1 (latest)
- Python 3.11.10 (latest micro release)

## Installation

This library supports [CPython v3.11][python]. Not tested on any other version.

1. Install the package from [PyPI][pypi] **(recommended)**:

- The latest stable release
- Potentially outdated

```shell
python3 -m pip install pku-lib
```

2. Install the package from [Codeberg][repo]:

- The most recent changes
- Potentially unstable

```shell
python3 -m pip install git+https://codeberg.org/wry/pku-lib
```

## Usage

To use the library, import `pku`.

```python
import pku

pku.hello()
```

## License

This library is licensed under the [GNU Affero General Public License][license]
version 3.0 or later.

<!-- Hyperlinks! -->

[python]: https://python.org/downloads/ "Download Python"
[pypi]: https://pypi.org/project/pku-lib/ "Python Package Index"
[repo]: https://codeberg.org/wry/pku-lib/ "Codeberg repository"
[license]: https://www.gnu.org/licenses/agpl-3.0.en.html "GNU Affero General Public License"
